#!/usr/bin/perl
###############################################################################
# 
# Create an appropriate ifcfg-* script in a new vserver s 
# /etc/sysconfig/network-scripts directory.
#
# $Id: buildIfCfg.pl,v 1.3 2003/10/02 21:47:06 cshapiro Exp $
# 
# Copyright (C) 2003 nuBridges llc
# Released under the Gnu General Public License, Version 2
# Copyright (C) 2003  nuBridges llc
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################
use strict;
use Getopt::Std;
use File::Basename;

use vars qw($opt_f);

#
# Usage message.
#
sub usage($)
{
	print("Usage: $_[0] -f vserver.conf");

	print<<EOU

	Create a new /etc/sysconfig/network-scripts/ifcfg-eth0:name 
	file in a new vserver, given the vserver configuration file.
EOU


}

#
# Return relevant part of config file text line or default if necessary.
#
sub doConfTextLine($$)
{
    my $retVal;
    my $textLine=$_[0];
    my $searchStr=$_[1];

    if( $textLine =~ /^$searchStr=\s*/ )
    {
        $retVal=$textLine;
        $retVal =~ s/^$searchStr=\s*//;
        $retVal =~ s/^"(.*)"$/$1/;

    }        
    $retVal;

}

#
# Main Line
#

if(! getopts("f:"))
{
	usage($0);
	exit 1;
}

if (! $opt_f)
{
	usage($0);
	exit(1);
}

my $vsName=basename($opt_f,".conf");
# print("VsName: $vsName\n");
my $outFileName="/vservers/$vsName/etc/sysconfig/network-scripts/ifcfg-eth0:$vsName";
# my $outFileName="./ifcfg-eth0:$vsName";

my $confFileName=$opt_f;

open(INFILE, "<$opt_f") || die("Error reading $opt_f: $!");

my $textLine;


my $iproot;
my $iprootmask;
my $iprootbcast;
my $iprootdev;
my $configVal;


while ($textLine = <INFILE>)
{
    chomp($textLine);
    $configVal="";
    if($configVal=doConfTextLine($textLine,"^IPROOT"))
    {
        $iproot=$configVal;
    }
    if($configVal=doConfTextLine($textLine,"^IPROOTMASK"))
    {
        $iprootmask=$configVal;
    }
    if($configVal=doConfTextLine($textLine,"^IPROOTBCAST"))
    {
        $iprootbcast=$configVal;
    }
    if($configVal=doConfTextLine($textLine,"^IPROOTDEV"))
    {
        $iprootdev=$configVal;
    }
}

# print("iproot: ",$iproot,"\n","iprootmask: ",$iprootmask,"\n");
# print("iprootbcast: ",$iprootbcast,"\n","iprootdev: ",$iprootdev,"\n");

if(! $iprootbcast)
{
    $iprootbcast="10.0.25.255";
}
if(! $iprootmask)
{
    $iprootmask="255.255.254.0";
}

open(OUTFILE, ">$outFileName") || die("Error opening $outFileName: $!");
print(OUTFILE "DEVICE=$iprootdev:$vsName\n");
print(OUTFILE "BOOTPROTO=static\n");
print(OUTFILE "BROADCAST=",$iprootbcast,"\n");
print(OUTFILE "IPADDR=",$iproot,"\n");
print(OUTFILE "NETMASK=",$iprootmask,"\n");
print(OUTFILE "NETWORK=10.0.24.0\n");
print(OUTFILE "ONBOOT=yes\n");

close(OUTFILE);
