#!/usr/bin/perl
#########################################################################
#
# Copy a file from inside a vserver to a directory accessible from 
# a non-privileged account on the vserver's support machine (the 
# 'vserver server'). Necessary for vsmaker.
#
# $Id: cpVSF.pl,v 1.5 2003/11/14 17:01:32 cshapiro Exp $
#
# Released under the Gnu General Public License, Version 2
# Copyright (C) 2003  nuBridges llc
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##########################################################################
use strict;
use File::Copy;
use File::Basename;
use File::Path;

# use Getopt::Std;

use vars qw( $VSDirectory);

#
# The thousandth usage message of my career.
#
sub usage($) {
	print("Usage: $_[0] [vservername:]filename [vservername:]filename\n");

	print<<EOU;
	Copy a file from one vserver to or from a directory acessible 
	to vsmaker. Or even from one vserver to another. First filename 
	is source,second is dest.
EOU

}


#
# Given a server name or nothing, assign it the directory on 
# the parent server.
#
sub assignDir($)
{
	my $retVal=$_[0];
	my $checkDir;

	if($retVal =~ m/:/)
	{
		($checkDir = $retVal) =~ s/:.+$//;
		$checkDir = $VSDirectory . "/" . $checkDir;
		if( ! -d $checkDir)
		{
			$retVal = "";
		}
		else
		{		
			$retVal =~ s/:/\//g;
			$retVal =~ s/\/\//\//g;
			$retVal= $VSDirectory . "/" . $retVal;
		}
	}
	$retVal;		
}

#
# Get checksum of a filename.
#
sub fileCksum($)
{
	my $filename=$_[0];
	
	open(SUM,"/usr/bin/cksum $filename |");
	my $sum=<SUM>;
	close(SUM);

	$sum;
}
#
# Copy a file from srcname to destname.
#
sub copyAFile($$)
{
	my $src=$_[0];
	my $dest=$_[1];
	
	my $srcSum;
	my $destSum;
	print("Copy ",$src, " to ", $dest, "\n");
	copy($src, $dest);
	if($dest !~ /^\/vservers/)
	{
		chown(78,78,($dest));
	}
	$srcSum=fileCksum($src);
	$destSum=fileCksum($dest);
	print($srcSum,"\t",$destSum,"\n");
}

#
# Copy all the files in a directory to another directory.
#
sub copyADir($$)
{
    my $src=$_[0];
    my $dest=$_[1];

    $dest=fixSlash($dest);
    opendir(SRCDIR,$src) || die("Cannot read directory $src: $!");
    my $filename;

    while($filename=readdir(SRCDIR))
    {
        if($filename !~ /^\.$|^\.\.$/)
        {
            copyAFile($src . "/" . $filename,$dest . $filename)
        }
    }

}
#
# Guarantee slash on end of directory name.
#
sub fixSlash($)
{

    my $dest = $_[0];

    if( $dest !~ /\/$/ )
    {
        $dest .= "/";
    }
    $dest;
}

#
# Main Line
#
$VSDirectory = "/vservers";
# $VSDirectory = "/tmp/vservers";

my $numArgs=scalar(@ARGV);

if ($numArgs != 2)
{
	usage($0);
	die(1);
}

my $src = assignDir($ARGV[0]);
my $dest = assignDir($ARGV[1]);

if((! $src) || (! $dest))
{
	usage($0);
	die(1);
}
if ( (! -f $src) && (! -d $src) )
{
	print("Source file or directory $src does not exist.\n");
	usage($0);
	die(1);
}

if( ( -f $src) && (( -f $dest) || ( ! -e $dest)) )
{
    copyAFile($src,$dest);
}
elsif ( (-f $src) && ( -d $dest) )
{        
    $dest=fixSlash($dest);    
    $dest=$dest . basename($src);
    copyAFile($src,$dest);
}
elsif ( ( -d $src) && ( -f $dest) )
{
    die("Oops. Cannot copy directory $src into file $dest.\n");
}
elsif ( ( -d $src) && ( -d $dest) )
{
    copyADir($src,$dest);
}
elsif ( ( -d $src) && ( ! -e $dest ) )
{    
    mkpath($dest);
    copyADir($src,$dest);
}

print("Done.\n");
