#!/bin/bash
############################################################################
#
# Make a new appliance vserver.
# 
# Copyright (C) 2003  nuBridges llc
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# $Id: mkVS.sh,v 1.6 2003/11/13 15:41:50 cshapiro Exp $
#
#############################################################################

#
# Usage message.
#
usage() 
{ 
    echo Usage: $1 [-c cloned-vserver-name ] -n vserver-name
    cat <<EOF
    Make a new vserver by the name of vserver-name. vserver-name
    can be no longer than 4 characters. Use "vsroot" as the base 
    or the -c ("cloned") vserver if passed.
EOF
}

#
# Main line
#
PARMSDIR=${HOME}/vbuild.params
VSERVERDIR=/vservers
VSERVERPARMSDIR=/etc/vservers
VSERVERDOMAIN=nubridges.net
VSROOTNAME="vsroot"

TEMP=`getopt -o "n:c:" -- "$@"`
eval set -- "$TEMP"

while true
do
    case "$1" in 
        -n) VSERVERNAME=$2; shift 2;;
        -c) VSROOTNAME=$2; shift 2;;
        --) shift; break;;
        *) echo Oops.; exit 1;;
    esac
done

if [ -z "$VSERVERNAME" ] 
then
    usage $0
    exit 1
fi

if [ `echo -n $VSERVERNAME | wc -c` -gt 4 ]
then
    echo Oops. $VSERVERNAME more than 4 characters long.
    usage $0
    exit 1
fi

if [ \( -f $VSERVERPARMSDIR/$VSERVERNAME.conf \) -a \( -d $VSERVERDIR/$VSERVERNAME \) ]
then
	echo Oops. $VSERVERNAME already exists. Creating it would be bad.
	usage $0
	exit 1
fi

IPADDR=`${HOME}/bin/nextIP.pl -f ${PARMSDIR}/current.ip.num -b 20 -n $VSERVERNAME.$VSERVERDOMAIN`

sed -e "s/^IPROOT=.*\$/IPROOT=$IPADDR/" -e "s/^S_HOSTNAME=.*\$/S_HOSTNAME=$VSERVERNAME.$VSERVERDOMAIN/" < $VSERVERPARMSDIR/$VSROOTNAME.conf > $VSERVERPARMSDIR/$VSERVERNAME.conf

cd $VSERVERDIR
echo "This part of the build may take up to 3 minutes."

vbuild $VSROOTNAME $VSERVERNAME
${HOME}/bin/nextMAC.pl -f ${PARMSDIR}/current.mac.num > $VSERVERDIR/$VSERVERNAME/tmp/FakeMACAddress.txt
${HOME}/bin/buildIfCfg.pl -f $VSERVERPARMSDIR/$VSERVERNAME.conf

echo Built $VSERVERNAME. Its IP address is $IPADDR. 


