#!/usr/bin/perl
######################################################
# 
# Retrieve the next MAC address.
#
# Copyright (C) 2003 nuBridges llc
# Released under the Gnu General Public License, Version 2
# Copyright (C) 2003  nuBridges llc
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# $Id: nextMAC.pl,v 1.3 2003/10/02 21:47:06 cshapiro Exp $
#
#####################################################
use strict;
use Getopt::Std;

use vars qw($opt_f $opt_t $opt_b);

sub usage($)
{
    print("Usage: $_[0] {-f filename} -b bottom -t top\n");
    print<<EOU
	Print the next  MAC address from filename to stdout.
	Use range between bottom and top if passed.
	(so "-b 5 -t 10" cycles through MAC addresses from 5 to 0A)
	Default is 1 -> 0xffff.	
EOU
}

#
# Main Line
#

my $MACStart="FE:FE:FE:";

if(! getopts("f:b:t:"))
{
    usage($0);
    exit 1;
}

if(! $opt_b)
{
	$opt_b=1;
}

if(! $opt_t)
{
	$opt_t=0xFFFFFF;
}

if (! $opt_f)
{
    usage($0);
    exit(1);
}
my $currentMAC;
my $currentMACHex;
my @MACList;
my $outMAC;

open(INFILE,"<$opt_f") || die ("Error reading $opt_f: $!");


$currentMAC = <INFILE>;
close(INFILE);
chomp($currentMAC);
$currentMAC =~ s/^$MACStart//; # FE:FE:FE:00:00:01 -> 00:00:01
$currentMAC =~ s/://g;    # 00:00:01 -> 000001

$currentMACHex=hex($currentMAC);

++$currentMACHex;

if($currentMACHex < $opt_b)
{
	#Underflow! Should  never happen. Handle anyway.
	$currentMACHex=$opt_b;
}

if($currentMACHex > $opt_t)
{
    #Overflow! Hope we are not using zero any more.
    $currentMACHex=$opt_b;
}

$currentMAC=sprintf("%6.6X",$currentMACHex);
$currentMAC =~ s/([0-9A-F][0-9A-F])/$1:/g;
$currentMAC =~ s/:$//;
$currentMAC = $MACStart . $currentMAC;

print($currentMAC);

open(OUTFILE, ">$opt_f") || die ("Error writing $opt_f: $!");
print(OUTFILE $currentMAC);
close(OUTFILE);




